@@ -19,7 +19,7 @@ Admin1Choropleth = R6Class("Admin1Choropleth",
       
       if (private$has_invalid_regions)
       {
-        warning("Please see ?country.regions for a list of mappable regions")
+        warning("Please use ?get_admin1_regions in the chroplethrAdmin1 package to get a list of mappable regions")
       }
     }
   )
@@ -37,8 +37,8 @@ Admin1Choropleth = R6Class("Admin1Choropleth",
 #' in the choroplethrAdmin1 package
 #' @param title An optional title for the map.  
 #' @param legend An optional name for the legend.  
-#' @param buckets The number of equally sized buckets to places the values in.  A value of 1 
-#' will use a continuous scale, and a value in [2, 9] will use that many buckets. 
+#' @param num_colors The number of colors on the map. A value of 1 
+#' will use a continuous scale. A value in [2, 9] will use that many colors. 
 #' @param zoom An optional vector of regions to zoom in on. Elements of this vector must exactly 
 #' match the names of regions as they appear in the "region" column of ?admin1.regions.
 
@@ -72,7 +72,7 @@ Admin1Choropleth = R6Class("Admin1Choropleth",
 #' @importFrom ggplot2 scale_fill_continuous scale_colour_brewer ggplotGrob annotation_custom 
 #' @importFrom scales comma
 #' @importFrom grid unit grobTree
-admin1_choropleth = function(country.name, df, title="", legend="", buckets=7, zoom=NULL)
+admin1_choropleth = function(country.name, df, title="", legend="", num_colors=7, zoom=NULL)
 {
   if (!requireNamespace("choroplethrAdmin1", quietly = TRUE)) {
     stop("Package choroplethrAdmin1 is needed for this function to work. Please install it.", call. = FALSE)
@@ -80,7 +80,7 @@ admin1_choropleth = function(country.name, df, title="", legend="", buckets=7, z
   c = Admin1Choropleth$new(country.name, df)
   c$title  = title
   c$legend = legend
-  c$set_buckets(buckets)
+  c$set_num_colors(num_colors)
   c$set_zoom(zoom)
   c$render()
 }
\ No newline at end of file
