@@ -16,10 +16,20 @@ head(county.regions)
 
 ## ------------------------------------------------------------------------
 county_choropleth(df_pop_county,
-                 title   = "2012 Population Estimates",
-                 legend  = "Population",
-                 buckets = 1,
-                 zoom    = c("california", "washington", "oregon"))
+                 title      = "2012 Population Estimates",
+                 legend     = "Population",
+                 num_colors = 1,
+                 state_zoom = c("california", "washington", "oregon"))
+
+## ------------------------------------------------------------------------
+# FIPS codes for Alameda, Contra Costa, Marin, Napa, San Francisco, San Mateo, Santa Clara, 
+# Solano, and Sonoma counties
+bay_area_counties = c(6001, 6013, 6041, 6055, 6075, 6081, 6085, 6095, 6097)
+county_choropleth(df_pop_county,
+                 title       = "2012 Population Estimates",
+                 legend      = "Population",
+                 num_colors  = 1,
+                 county_zoom = bay_area_counties)
 
 ## ------------------------------------------------------------------------
 library(ggplot2)
