@@ -17,17 +17,23 @@ test_that("setting legend returns ggplot", {
 
 test_that("continuous scale returns ggplot", {
   data(df_pop_county)
-  expect_is(county_choropleth(df_pop_county, buckets=1), "ggplot")
+  expect_is(county_choropleth(df_pop_county, num_colors=1), "ggplot")
 })
 
 test_that("west coast zoom returns ggplot", {
   data(df_pop_county)
-  expect_is(county_choropleth(df_pop_county, zoom=c("california", "oregon", "washington")), "ggplot")
+  expect_is(county_choropleth(df_pop_county, state_zoom=c("california", "oregon", "washington")), "ggplot")
+})
+
+test_that("nyc county zoom returns ggplot", {
+  data(df_pop_county)
+  nyc_county_fips = c(36005, 36047, 36061, 36081, 36085)
+  county_choropleth(df_pop_county, num_colors=1, county_zoom=nyc_county_fips)
 })
 
 test_that("error on invalid zoom", {
   data(df_pop_county)
-  expect_error(county_choropleth(df_pop_county, zoom="asdf"))  
+  expect_error(county_choropleth(df_pop_county, state_zoom="asdf"))  
 })
 
 test_that("less than full counties emits warning", {
